@@ -3,13 +3,16 @@ package Firefox::Util::Profile;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-19'; # DATE
 our $DIST = 'Firefox-Util-Profile'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
+use Exporter 'import';
+our @EXPORT_OK = qw(list_firefox_profiles);
+
 our %SPEC;
 
 $SPEC{list_firefox_profiles} = {
@@ -86,7 +89,7 @@ Firefox::Util::Profile - List available Firefox profiles
 
 =head1 VERSION
 
-This document describes version 0.002 of Firefox::Util::Profile (from Perl distribution Firefox-Util-Profile), released on 2020-04-19.
+This document describes version 0.003 of Firefox::Util::Profile (from Perl distribution Firefox-Util-Profile), released on 2020-04-19.
 
 =head1 SYNOPSIS
 
@@ -106,7 +109,7 @@ List available Firefox profiles.
 This utility will read ~/.mozilla/firefox/profiles.ini and extracts the list of
 profiles.
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
